@@ -54,6 +54,15 @@ class Node(MeshDevice):
                 ret["latest_date"] = ret["date"] if "date" in ret else None
         return ret
 
+    @property
+    def hardware_version(self) -> str:
+        """Get the hardware version of the node
+
+        :return: A string containing the hardware version
+        """
+
+        return self.__attributes.get("model", {}).get("hardwareVersion")
+
     @property
     def manufacturer(self) -> str:
         """Get the node manufacturer
